@@ -22,16 +22,14 @@ from libopensesame.var_store import var_store
 import warnings
 from libopensesame.exceptions import osexception
 from libopensesame import debug
-try:
-	import pygame
-except:
-	pygame = None
+
 
 class item(object):
 
 	"""Abstract class that serves as the basis for all OpenSesame items."""
 
 	encoding = u'utf-8'
+	__deepcopy__ = None
 
 	def __init__(self, name, experiment, string=None):
 
@@ -50,7 +48,6 @@ class item(object):
 			object.__getattr__(self, u'var')
 		except:
 			self.var = var_store(self, parent=experiment.var)
-		self.reset()
 		self.name = name
 		self.experiment = experiment
 		self.debug = debug.enabled
@@ -282,7 +279,7 @@ class item(object):
 
 		debug.msg()
 		textblock_var = None
-		self.variables = {}
+		self.var.clear()
 		self.reset()
 		self.comments = []
 		if string is None:
