@@ -85,28 +85,46 @@ class qtitem_store(item_store):
 			self[_name].remove_child_item(name, index=-1)
 		self.extension_manager.fire(u'delete_item', name=name)
 
-	def new(self, _type, name=None, script=None, catch_exceptions=True):
+	def new(
+		self, _type, name=None, script=None, catch_exceptions=True,
+		allow_rename=True
+	):
 
 		"""See item_store."""
 
 		import warnings
+
 		with warnings.catch_warnings(record=True) as warning_list:
 			if catch_exceptions:
 				try:
-					item = super(qtitem_store, self).new(_type, name=name,
-						script=script)
+					item = super(qtitem_store, self).new(
+						_type=_type,
+						name=name,
+						script=script,
+						allow_rename=allow_rename
+					)
 				except Exception as e:
 					if not isinstance(e, osexception):
 						e = osexception(e)
 					self.error_log.append(e)
 					return
 			else:
-				item = super(qtitem_store, self).new(_type, name=name,
-					script=script)
+				item = super(qtitem_store, self).new(
+					_type=_type,
+					name=name,
+					script=script,
+					allow_rename=allow_rename
+				)
 		if warning_list:
 			import yaml
 			import os
-			self.tabwidget.open_help(os.path.join(u'help', u'new_item_warning'))
+			try:
+				self.tabwidget.open_help(
+					os.path.join(u'help', u'new_item_warning'))
+			except AttributeError:
+				# In case the experiment object doesn't exist yet, which causes
+				# the help page to fail.
+				pass
 			self.console.write(yaml.dump(warning_list))
 		self.main_window.set_unsaved(True)
 		return item
@@ -219,3 +237,14 @@ class qtitem_store(item_store):
 		if _type in self.built_in_types:
 			return True
 		return False
+
+	def clear_cache(self):
+
+		"""
+		desc:
+			Clears the cache, currently only the cache with children for each
+			item.
+		"""
+
+		for item in self.values():
+			item._children = None
