@@ -20,7 +20,6 @@ along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 from libopensesame.py3compat import *
 import warnings
 import random
-import pygame
 import math
 from libopensesame.exceptions import osexception
 from openexp.backend import Backend, configurable
@@ -405,6 +404,17 @@ class Canvas(Backend):
 
 		return len(self._elements)
 
+	def __contains__(self, key):
+
+		"""
+		visible: False
+
+		desc:
+			Checks whether a named element is in the Canvas.
+		"""
+
+		return key in self._elements
+
 	def __iter__(self):
 
 		"""
@@ -1373,7 +1383,7 @@ class Canvas(Backend):
 		desc:		deprecated
 		"""
 
-		self.bgcolor = self.color
+		self.background_color = color
 
 	def set_font(self, style=None, size=None, italic=None, bold=None,
 		underline=None):
@@ -1480,6 +1490,8 @@ def _gabor(orient, freq, env=u"gaussian", size=96, stdev=12, phase=0,
 		see [canvas.gabor].
 	"""
 
+	import pygame
+
 	env = _match_env(env)
 	# Generating a Gabor patch takes quite some time, so keep
 	# a cache of previously generated Gabor patches to speed up
@@ -1556,6 +1568,8 @@ def _noise_patch(env=u"gaussian", size=96, stdev=12, col1=u"white",
 		see [canvas.noise_patch].
 	"""
 
+	import pygame
+
 	env = _match_env(env)
 	# Generating a noise patch takes quite some time, so keep
 	# a cache of previously generated noise patches to speed up
